# Python – 关键字

> 原文： [https://howtodoinjava.com/python/python-keywords/](https://howtodoinjava.com/python/python-keywords/)

**Python 关键字**是 [python](https://howtodoinjava.com/python-tutorial/) 编程语言的保留字。 这些关键字不能用于其他目的。

Python 中有 35 个关键字 - 下面列出了它们的用法。

| 关键词 | 描述 |
| **和** | A **logical AND** operator. Return `True` if both statements are `True`.

```java
			x = (5 > 3 and 5 < 10)
			print(x)	# True

```

 |
| **或** | A **logical OR** operator. Returns `True` if either of two statements is true. If both statements are false, the returns `False`.

```java
			x = (5 > 3 or 5 > 10)
			print(x)	# True

```

 |
| **作为** | It is used to create an alias.

```java
			import calendar as c
			print(c.month_name[1])	#January

```

 |
| **断言** | It can be used for debugging the code. It tests a condition and returns `True` , if not, the program will raise an AssertionError.

```java
		x = "hello"

		assert x == "goodbye", "x should be 'hello'"  # AssertionError

```

 |
| **异步** | It is used to declare a function as a coroutine, much like what the `@asyncio.coroutine` decorator does.

```java
async def ping_server(ip):
```

 |
| **等待** | It is used to call `async` coroutine.

```java
		async def ping_local():
    		return await ping_server('192.168.1.1')

```

 |
| **类** | It is used to create a class.

```java
		class User:
		  name = "John"
		  age = 36

```

 |
| **def** | It is used to create or define a function.

```java
		def my_function():
		  print("Hello world !!")

		my_function()

```

 |
| 的 | It is used to delete objects. In Python everything is an object, so the `del` keyword can also be used to delete variables, [lists](https://howtodoinjava.com/python/python-lists/), or parts of a list, etc.

```java
		x = "hello"

		del x

```

 |
| 如果为 | It is used to create conditional statements that allows us to execute a block of code only if a condition is `True`.

```java
		x = 5

		if x > 3:
		  print("it is true")

```

 |
| **elif** | It is used in conditional statements and is short for `else if`.

```java
		i = 5

		if i > 0:
	        print("Positive")
	    elif i == 0:
	        print("ZERO")
	    else:
	        print("Negative")

```

 |
| **其他** | It decides what to do if the condition is `False` in `if..else` statement.

```java
		i = 5

		if i > 0:
	        print("Positive")
	    else:
	        print("Negative")

```

也可以在`try...except`块中使用。

```java
		x = 5

		try:
		    x > 10
		except:
		    print("Something went wrong")
		else:
		    print("Normally execute the code")

```

 |
| **试试** | 如果它包含任何错误，它将定义一个测试代码块。 |
| 除了 | It defines a block of code to run if the try block raises an error.

```java
		try:
		    x > 3
		except:
		    print("Something went wrong")

```

 |
| **终于** | It defines a code block which will be executed no matter if the try block raises an error or not.

```java
		try:
		    x > 3
		except:
		    print("Something went wrong")
		finally:
			 print("I will always get executed")

```

 |
| **加注** | It is used to raise an exception, manually.

```java
		x = "hello"

		if not type(x) is int:
		  	raise TypeError("Only integers are allowed")

```

 |
| **错误** | 它是一个布尔值，与 0 相同。 |
| **正确** | 它是一个布尔值，与 1 相同。 |
| 的 | It is used to create a for loop. A for loop can be used to iterate through a sequence, like a list, tuple, etc.

```java
		for x in range(1, 9):
  			print(x)

```

 |
| **而** | It is used to create a while loop. The loop continues until the conditional statement is false.

```java
		x = 0

		while x < 9:
		  	print(x)
		  	x = x + 1

```

 |
| **中断** | It is used to break out a for loop, or a while loop.

```java
		i = 1 

		while i < 9:
		  	print(i)
		  	if i == 3:
		    	break
		  	i += 1

```

 |
| **继续** | It is used to end the current iteration in a for loop (or a while loop), and continues to the next iteration.

```java
		for i in range(9):
		  	if i == 3:
		    	continue
		  	print(i)

```

 |
| 进口 | It is used to import modules.

```java
import datetime
```

 |
| 中的 | It is used to import only a specified section from a module.

```java
from datetime import time
```

 |
| **全局** | It is used to create global variables from a no-global scope, e.g. inside a function.

```java
		def myfunction():
		  	global x
		  	x = "hello"

```

 |
| 中的 | 1\. It is used to check if a value is present in a sequence (list, range, string etc.).
2\. It is also used to iterate through a sequence in a `for` loop.

```java
		fruits = ["apple", "banana", "cherry"]

		if "banana" in fruits:
		  	print("yes")

		for x in fruits:
  			print(x)

```

 |
| **是** | It is used to test if two variables refer to the same object.

```java
		a = ["apple", "banana", "cherry"]
		b = ["apple", "banana", "cherry"]
		c = a

		print(a is b)	# False
		print(a is c)	# True

```

 |
| **lambda** | It is used to create small anonymous functions. They can take any number of arguments, but can only have one expression.

```java
		x = lambda a, b, c : a + b + c

		print(x(5, 6, 2))

```

 |
| **无** | It is used to define a `null` value, or no value at all. None is not the same as 0, False, or an empty string.
None is a datatype of its own (*NoneType*) and only None can be None.

```java
		x = None

		if x:
		  print("Do you think None is True")
		else:
		  print("None is not True...")		# Prints this statement

```

 |
| **非本地** | It is used to declare that a variable is not local. It is used to work with variables inside nested functions, where the variable should not belong to the inner function.

```java
		def myfunc1():
		  	x = "John"
		  	def myfunc2():
		    	nonlocal x
		    	x = "hello"
		  	myfunc2()
		  	return x

		print(myfunc1())

```

 |
| **不是** | It is a logical operator and reverses the value of True or False.

```java
		x = False

		print(not x)	# True

```

 |
| **通过** | It is used as a placeholder for future code. When the pass statement is executed, nothing happens, but you avoid getting an error when an empty code is not allowed.循环，函数定义，类定义或 if 语句中不允许使用空代码。

```java
for x in [0, 1, 2]:
  			pass
```

 |
| **返回** | It is to exit a function and return a value.

```java
def myfunction():
  			return 3+3
```

 |
| **与** | 用于简化异常处理 |
| **产量** | 要结束一个函数，返回一个生成器 |

学习愉快！

参考： [W3 学校](https://www.w3schools.com/python/python_ref_keywords.asp)